@@ -34,6 +34,12 @@ async def _default_response_handler(success_message: str, response: dict) -> Non
 response_function: Callable[[str, dict], Awaitable[None]] = _default_response_handler
 
 
+def restart_slapp():
+    global slapp_loop, slapp_write_queue
+    slapp_loop = False
+    slapp_write_queue.put('')
+
+
 async def _read_stdout(stdout):
     global response_function
     global slapp_loop
@@ -84,10 +90,13 @@ async def _write_stdin(stdin):
         try:
             while not slapp_write_queue.empty():
                 query = await slapp_write_queue.get()
-                logging.debug(f'_write_stdin: writing {query}')
-                stdin.write(f'{query}\n'.encode('utf-8'))
-                await stdin.drain()
-                await asyncio.sleep(0.1)
+                if slapp_loop:
+                    logging.debug(f'_write_stdin: writing {query}')
+                    stdin.write(f'{query}\n'.encode('utf-8'))
+                    await stdin.drain()
+                    await asyncio.sleep(0.1)
+                else:
+                    return
             await asyncio.sleep(1)
         except Exception as e:
             logging.error(f'_write_stdin EXCEPTION: {traceback.format_exc()}', exc_info=e)
@@ -114,8 +123,10 @@ async def _run_slapp(slapp_path: str, mode: str, restart_on_fail: bool = True):
             _read_stdout(proc.stdout),
             _write_stdin(proc.stdin)
         )
-        logging.warning("_run_slapp returned!")
-        if not restart_on_fail:
+        if restart_on_fail:
+            logging.info("_run_slapp: asyncio tasks finished! Restarting ...")
+        else:
+            logging.info("_run_slapp: asyncio tasks finished!")
             break
 
 
@@ -127,7 +138,8 @@ async def initialise_slapp(new_response_function: Callable[[str, dict], Any], mo
     assert os.path.isfile(slapp_console_path), f'{slapp_console_path=} not a file, expected .dll'
     assert os.path.isdir(SLAPP_DATA_FOLDER), f'{SLAPP_DATA_FOLDER=} not a directory.'
     response_function = new_response_function
-    await _run_slapp(slapp_console_path, mode, restart_on_fail=(mode == "--keepOpen"))
+    restart_on_fail = mode == "--keepOpen"
+    await _run_slapp(slapp_console_path, mode, restart_on_fail=restart_on_fail)
 
 
 def conditionally_add_option(options, query: str, typed_option_no_delimit: str, query_option_to_add: str) -> str:
